%include goptions;

%include data(iris);

*-- create observation ID variable to label points by Species;
data iris;
	set iris;
	id = put(spec_no,1.0);

title;

*goptions hsize= vsize=;
*-- Obtain biplot scores (_type_='OBS') and variable vectors (_type_='VAR');
%biplot(data=iris,
   var=SepalLen SepalWid PetalLen PetalWid, 
   id=id,            /* observation ID, here, species number */
   std=std,          /* standardize to mean=0, var=1         */
   scale=0.36,       /* Scale factor for variable vectors    */
   m0=0.1,           /* size of origin marker                */
   htext=1.5 2,      /* text heights for obs. and var labels */
   xextra=0 1,       /* extra tick mark for labels           */
   gplot=no,         /* suppress the plot                    */
   colors=black,     /* we change these later                */
   out=biplot,       /* output coordinates data set          */
   anno=bianno);     /* output Annotate data set             */

*-- Customize the Annotate data set;
data bianno;
   set bianno;
   if _type_='OBS' then do;
      *-- change colors;
      select(_name_);
         when ('3') color='RED';
         when ('2') color='GREEN';
         when ('1') color='BLUE';
         otherwise;
       end;
      end;
   *-- adjust label position to avoid overplotting;
   else /*if _type_='VAR' then */ do;
      if _name_='PetalLen' and function='LABEL' then position='E';
      end;
run;

*-- Select just the observation scores;
data biplobs;
   set biplot;
   where (_type_='OBS');
   run;
   
*-- Obtain data ellipses for each group and total sample;
%ellipses(data=biplobs, 
   x=dim1, y=dim2,      /* data ellipses for biplot dimension */
   group=_name_,        
   all=yes,             /* include total sample ellipse */           
   colors=blue green red gray, 
   out=contour,         /* output data set */ 
   plot=no,             /* suppress the plot */ 
   pvalue=0.68,
   vaxis=axis98,        /* use AXIS statements generated by %biplot */
   haxis=axis99
   out=ellipses        /* output Annotate data set */ 
   );


*-- Join the biplot annotations and the data ellipses;
data bianno;
   set bianno contour;
   run;

*-- Plot the observations along with annnotations;
symbol1 v=none;
proc gplot data=biplot;
   plot dim2 * dim1 / 
      anno=bianno frame
      vaxis=axis98 haxis=axis99 
      vminor=1 hminor=1;
run;


