%include data(soils);

title 'Canonical HE plots for two-way design';
/* Randomized Block Design Model */

title2 'Multivariate Analysis of Variance';
proc glm data=soils outstat=HEstats;
 Class Block Contour Depth;
 model pH--Conduc = Block Contour | Depth / NoUni SS3;
 manova H=Block Contour*Depth Contour Depth / PrintE;
run;
quit;

%include goptions;
*hemat(data=soils,stat=HEstats, 
	var= ph N P Mg K Na,
	effect=Contour
     );
*hemat(data=soils,stat=HEstats, 
	var= ph N P Mg K Na,
	effect=Depth
     );

title;

legend1 position=(inside bottom left) mode=protect;
%caption(All groups, x=50, htext=2, out=_title_);
%canplot(data=soils,  class=Gp,
   var=pH--Conduc, 
   inc=2 2, yextra=1 0, xextra=0 1, scale=5,
   annoadd=mean gplabel _title_,
   colors=red blue green brown,
   legend=legend1
   );
%gskip;
   
%caption(Soil depth, x=50, htext=2, out=_title_);
%canplot(data=soils,  class=depth,
   var=pH--Conduc,
   annoadd=mean gplabel _title_, 
   legend=legend1, yextra=1 0
   );
%gskip;

%caption(Soil contours, x=50, htext=2, out=_title_);
%canplot(data=soils,  class=contour,
   var=pH--Conduc, legend=legend1, scale=7,
   annoadd=mean gplabel _title_
   );
%gskip;
   
*-- Cannonical plot to display the Contour*Depth interaction;
proc glm data=soils outstat=HEstats;
 class Block Contour Depth Gp;
 model pH--Conduc = Block Contour Depth  / NoUni SS3;
 output out=Resids 
    Residuals=pH N Dens P Ca Mg K Na Conduc;

%caption(Depth*Contour Effect, htext=2, out=_title_);
%canplot(data=Resids,  class=Gp,
   var=pH2--Conduc2,  
   inc=2 2, scale=5, 
   conf=.50,
   colors=red blue green brown,
   annoadd=mean _title_,
   legend=legend1,
   out=canscores,
   anno=cananno
   );
%gskip;

*-- Remove conf. circles;
data cananno;
   set cananno;
   where comment not in ('CIRCLE');
   run;

*-- Cannonical HE plot for the Contour*Depth interaction;
proc glm data=canscores outstat=CANstats;
   class Gp;
   model can1 can2 = Gp / nouni ss3;
   manova h=Gp;

axis98 length=5.42 IN order=(-2 to 3) label=(a=90) ;  *-- 5.42=6.5 * 5/6;
axis99 length=6.5  IN order=(-3 to 3) ;
%heplot(data=canscores, stat=CANstats,
   x=can1, y=can2,
   effect=Gp,
   legend=none,
   vaxis=axis98, haxis=axis99,
   anno=cananno
	);
